# P2Pool

Graphs

Version:

Pool rate: ( DOA+orphan) Share difficulty:

Node uptime: Peers: out, in

Local rate: ( DOA) Expected time to share:

Shares: total ( orphaned, dead) Efficiency:

Payout if a block were found NOW: to . Expected after mining for 24 hours: per block.

Current block value: Expected time to block:

## Share explorer

Best share:

Verified heads:

Heads:

Verified tails:

Tails:

My shares:

## Blocks found in last day:

Note that blocks may have been orphaned from the P2Pool chain and so not be here.

time | number | hash/explorer link | share
--- | --- | --- | ---

## Payouts if a block were found NOW:

address | amount in
--- | ---